@@ -19,10 +19,17 @@ class CheckFailed(AssertionError):
 
     __module__ = "builtins"
     context: Optional[FailureContext]
+    causes: Optional[Tuple[Union["CheckFailed", AssertionError], ...]]
 
-    def __init__(self, *args: Any, context: Optional[FailureContext] = None):
+    def __init__(
+        self,
+        *args: Any,
+        context: Optional[FailureContext] = None,
+        causes: Optional[Tuple[Union["CheckFailed", AssertionError], ...]] = None,
+    ):
         super().__init__(*args)
         self.context = context
+        self.causes = causes
 
 
 def make_unique_by_key(
@@ -176,7 +183,7 @@ class SchemaLoadingError(ValueError):
 class NonCheckError(Exception):
     """An error happened in side the runner, but is not related to failed checks.
 
-    Used primarily to not let Hypothesis to consider the test as flaky or detect multiple failures as we handle it
+    Used primarily to not let Hypothesis consider the test as flaky or detect multiple failures as we handle it
     on our side.
     """
 
@@ -189,6 +196,12 @@ class InternalError(Exception):
     __module__ = "builtins"
 
 
+class SkipTest(BaseException):
+    """Raises when a test should be skipped and return control to the execution engine (own Schemathesis' or pytest)."""
+
+    __module__ = "builtins"
+
+
 SERIALIZATION_NOT_POSSIBLE_MESSAGE = (
     f"Schemathesis can't serialize data to any of the defined media types: {{}} \n{SERIALIZERS_SUGGESTION_MESSAGE}"
 )
