@@ -1,14 +1,18 @@
 from inspect import signature
-from typing import Any, Callable, Dict, Generator, Optional, Union
+from typing import Any, Callable, Dict, Generator, Optional, Type, Union
 
 import attr
 import pytest
 from _pytest.fixtures import FixtureRequest
 from hypothesis.core import HypothesisHandle
+from hypothesis.errors import Flaky, MultipleFailures
+from hypothesis.internal.escalation import format_exception, get_interesting_origin, get_trimmed_traceback
+from hypothesis.internal.reflection import impersonate
 from pytest_subtests import SubTests, nullcontext
 
-from .constants import CodeSampleStyle, DataGenerationMethod
-from .exceptions import InvalidSchema
+from .auth import AuthStorage
+from .constants import FLAKY_FAILURE_MESSAGE, CodeSampleStyle, DataGenerationMethod
+from .exceptions import CheckFailed, InvalidSchema, SkipTest, get_grouped_exception
 from .hooks import HookDispatcher, HookScope
 from .models import APIOperation
 from .schemas import BaseSchema
@@ -37,6 +41,7 @@ class LazySchema:
     operation_id: Optional[Filter] = attr.ib(default=NOT_SET)  # pragma: no mutate
     app: Any = attr.ib(default=NOT_SET)  # pragma: no mutate
     hooks: HookDispatcher = attr.ib(factory=lambda: HookDispatcher(scope=HookScope.SCHEMA))  # pragma: no mutate
+    auth: AuthStorage = attr.ib(factory=AuthStorage)  # pragma: no mutate
     validate_schema: bool = attr.ib(default=True)  # pragma: no mutate
     skip_deprecated_operations: bool = attr.ib(default=False)  # pragma: no mutate
     data_generation_methods: Union[DataGenerationMethodInput, NotSet] = attr.ib(default=NOT_SET)
@@ -96,6 +101,7 @@ class LazySchema:
                     tag=tag,
                     operation_id=operation_id,
                     hooks=self.hooks,
+                    auth=self.auth if self.auth.provider is not None else NOT_SET,
                     test_function=test,
                     validate_schema=validate_schema,
                     skip_deprecated_operations=skip_deprecated_operations,
@@ -174,10 +180,64 @@ def run_subtest(
     subtests: SubTests,
 ) -> None:
     """Run the given subtest with pytest fixtures."""
+    __tracebackhide__ = True  # pylint: disable=unused-variable
+
+    # Deduplicate found checks in case of Hypothesis finding multiple of them
+    failed_checks = {}
+    exceptions = []
+    inner_test = sub_test.hypothesis.inner_test  # type: ignore
+
+    @impersonate(inner_test)  # type: ignore
+    def collecting_wrapper(*args: Any, **kwargs: Any) -> None:
+        __tracebackhide__ = True  # pylint: disable=unused-variable
+        try:
+            inner_test(*args, **kwargs)
+        except CheckFailed as failed:
+            failed_checks[failed.__class__] = failed
+            raise failed
+        except Exception as exception:
+            # Deduplicate it later, as it is more costly than for `CheckFailed`
+            exceptions.append(exception)
+            raise
+
+    def get_exception_class() -> Type[CheckFailed]:
+        return get_grouped_exception("Lazy", *failed_checks.values())
+
+    sub_test.hypothesis.inner_test = collecting_wrapper  # type: ignore
+
     with subtests.test(
         verbose_name=operation.verbose_name, data_generation_method=data_generation_method.as_short_name()
     ):
-        sub_test(**fixtures)
+        try:
+            sub_test(**fixtures)
+        except SkipTest as exc:
+            pytest.skip(exc.args[0])
+        except MultipleFailures as exc:
+            # Hypothesis doesn't report the underlying failures in these circumstances, hence we display them manually
+            exc_class = get_exception_class()
+            failures = "".join(f"{SEPARATOR} {failure.args[0]}" for failure in failed_checks.values())
+            unique_exceptions = {get_interesting_origin(exception): exception for exception in exceptions}
+            message = (
+                f"Schemathesis found {len(failed_checks) + len(unique_exceptions)} distinct sets of failures.{failures}"
+            )
+            for exception in unique_exceptions.values():
+                # Non-check exceptions
+                message += f"{SEPARATOR}\n\n"
+                tb = get_trimmed_traceback(exception)
+                message += format_exception(exception, tb)
+            raise exc_class(message, causes=tuple(failed_checks.values())).with_traceback(exc.__traceback__) from None
+        except Flaky as exc:
+            exc_class = get_exception_class()
+            failure = next(iter(failed_checks.values()))
+            message = f"{FLAKY_FAILURE_MESSAGE}{failure}"
+            # The outer frame is the one for user's test function, take it as the root one
+            traceback = exc.__traceback__.tb_next
+            # The next one comes from Hypothesis internals - remove it
+            traceback.tb_next = None
+            raise exc_class(message, causes=tuple(failed_checks.values())).with_traceback(traceback) from None
+
+
+SEPARATOR = "\n===================="
 
 
 def _schema_error(
@@ -206,6 +266,7 @@ def get_schema(
     app: Any = None,
     test_function: GenericTest,
     hooks: HookDispatcher,
+    auth: Union[AuthStorage, NotSet],
     validate_schema: Union[bool, NotSet] = NOT_SET,
     skip_deprecated_operations: Union[bool, NotSet] = NOT_SET,
     data_generation_methods: Union[DataGenerationMethodInput, NotSet] = NOT_SET,
@@ -224,6 +285,7 @@ def get_schema(
         app=app,
         test_function=test_function,
         hooks=schema.hooks.merge(hooks),
+        auth=auth,
         validate_schema=validate_schema,
         skip_deprecated_operations=skip_deprecated_operations,
         data_generation_methods=data_generation_methods,
