@@ -423,6 +423,7 @@ class Case:  # pylint: disable=too-many-public-methods
             argument.
         :param code_sample_style: Controls the style of code samples for failure reproduction.
         """
+        __tracebackhide__ = True  # pylint: disable=unused-variable
         from .checks import ALL_CHECKS  # pylint: disable=import-outside-toplevel
 
         checks = checks or ALL_CHECKS
@@ -451,7 +452,8 @@ class Case:  # pylint: disable=too-many-public-methods
                 f"----------\n\n"
                 f"Response status: {response.status_code}\n"
                 f"Response payload: `{payload}`\n\n"
-                f"{code_message}"
+                f"{code_message}",
+                causes=tuple(failed_checks),
             )
 
     def _get_code_message(self, code_sample_style: CodeSampleStyle, request: requests.PreparedRequest) -> str:
@@ -472,6 +474,7 @@ class Case:  # pylint: disable=too-many-public-methods
         code_sample_style: Optional[str] = None,
         **kwargs: Any,
     ) -> requests.Response:
+        __tracebackhide__ = True  # pylint: disable=unused-variable
         response = self.call(base_url, session, headers, **kwargs)
         self.validate_response(response, checks, code_sample_style=code_sample_style)
         return response
@@ -666,6 +669,9 @@ class APIOperation(Generic[P, C]):
             strategy = _apply_hooks(hooks, strategy)
         return strategy
 
+    def get_security_requirements(self) -> List[str]:
+        return self.schema.get_security_requirements(self)
+
     def get_strategies_from_examples(self) -> List[st.SearchStrategy[Case]]:
         """Get examples from the API operation."""
         return self.schema.get_strategies_from_examples(self)
@@ -693,6 +699,7 @@ class APIOperation(Generic[P, C]):
             method=self.method,  # string, immutable
             definition=deepcopy(self.definition),
             schema=self.schema.clone(),  # shallow copy
+            verbose_name=self.verbose_name,  # string, immutable
             app=self.app,  # not deepcopyable
             base_url=self.base_url,  # string, immutable
             path_parameters=deepcopy(self.path_parameters),
@@ -775,6 +782,7 @@ class Status(str, Enum):
     success = "success"  # pragma: no mutate
     failure = "failure"  # pragma: no mutate
     error = "error"  # pragma: no mutate
+    skip = "skip"  # pragma: no mutate
 
 
 @attr.s(slots=True, repr=False)  # pragma: no mutate
@@ -826,7 +834,7 @@ class Request:
             uri=uri,
             method=method,
             headers={key: [value] for (key, value) in prepared.headers.items()},
-            body=base64.b64encode(body).decode() if body is not None else body,
+            body=serialize_payload(body) if body is not None else body,
         )
 
 
@@ -948,6 +956,8 @@ class TestResult:
     interactions: List[Interaction] = attr.ib(factory=list)  # pragma: no mutate
     logs: List[LogRecord] = attr.ib(factory=list)  # pragma: no mutate
     is_errored: bool = attr.ib(default=False)  # pragma: no mutate
+    is_flaky: bool = attr.ib(default=False)  # pragma: no mutate
+    is_skipped: bool = attr.ib(default=False)  # pragma: no mutate
     seed: Optional[int] = attr.ib(default=None)  # pragma: no mutate
     # To show a proper reproduction code if an error happens and there is no way to get actual headers that were
     # sent over the network. Or there could be no actual requests at all
@@ -956,6 +966,12 @@ class TestResult:
     def mark_errored(self) -> None:
         self.is_errored = True
 
+    def mark_flaky(self) -> None:
+        self.is_flaky = True
+
+    def mark_skipped(self) -> None:
+        self.is_skipped = True
+
     @property
     def has_errors(self) -> bool:
         return bool(self.errors)
@@ -1053,7 +1069,11 @@ class TestResultSet:
 
     @property
     def passed_count(self) -> int:
-        return self._count(lambda result: not result.has_errors and not result.has_failures)
+        return self._count(lambda result: not result.has_errors and not result.is_skipped and not result.has_failures)
+
+    @property
+    def skipped_count(self) -> int:
+        return self._count(lambda result: result.is_skipped)
 
     @property
     def failed_count(self) -> int:
