@@ -30,6 +30,7 @@ from ...exceptions import (
     InvalidRegularExpression,
     InvalidSchema,
     NonCheckError,
+    SkipTest,
     get_grouped_exception,
 )
 from ...hooks import HookContext, get_all_by_name
@@ -305,15 +306,8 @@ def run_test(  # pylint: disable=too-many-locals
         # They raise different "grouped" exceptions, and `MultipleFailures` is risen as the result
         status = Status.failure
     except hypothesis.errors.Flaky:
-        status = Status.error
-        result.mark_errored()
-        result.add_error(
-            hypothesis.errors.Flaky(
-                "Tests on this API operation produce unreliable results: \n"
-                "Falsified on the first call but did not on a subsequent one"
-            ),
-            result.checks[-1].example if result.checks else None,
-        )
+        status = Status.failure
+        result.mark_flaky()
     except hypothesis.errors.Unsatisfiable:
         # We need more clear error message here
         status = Status.error
@@ -321,6 +315,9 @@ def run_test(  # pylint: disable=too-many-locals
     except KeyboardInterrupt:
         yield events.Interrupted()
         return
+    except SkipTest:
+        status = Status.skip
+        result.mark_skipped()
     except AssertionError as exc:  # comes from `hypothesis-jsonschema`
         error = reraise(exc)
         status = Status.error
@@ -450,7 +447,7 @@ def run_checks(
             result.add_success("max_response_time", case, response, elapsed_time)
 
     if errors:
-        raise get_grouped_exception(case.operation.verbose_name, *errors)
+        raise get_grouped_exception(case.operation.verbose_name, *errors)(causes=tuple(errors))
 
 
 def run_targets(targets: Iterable[Callable], context: TargetContext) -> None:
