@@ -115,11 +115,13 @@ def dict_not_none_values(**kwargs: Any) -> Dict[str, Any]:
 
 IGNORED_PATTERNS = (
     "Falsifying example: ",
+    "Falsifying explicit example: ",
     "You can add @seed",
     "Failed to reproduce exception. Expected:",
     "Flaky example!",
     "Traceback (most recent call last):",
     "You can reproduce this example by temporarily",
+    "Unreliable test timings",
 )
 
 
